xquery version "3.1";

module namespace kmg-edition-nav="https://mollenhauer-edition.de/ns/edition-nav";

declare namespace tei="http://www.tei-c.org/ns/1.0";
declare namespace xhtml="http://www.w3.org/1999/xhtml";
declare namespace sade="https://mollenhauer-edition.de/ns/sade";

import module namespace config="https://sade.textgrid.de/ns/config" at "../config.xqm";
import module namespace transformKMG="http://mollenhauer-edition.de/ns/transform" at "transform.xqm";

declare function kmg-edition-nav:get-editions($node as node(), $model as map(*))
{
    for $doc in collection($config:sade-data)
    order by
        string-join($doc//tei:title[@type="main"]//text())
        => replace("[\s‹›«»›‹»«‘’“”‚‘„“]", "")
        => replace("Ü", "U")
        => replace("Ä", "A")
        => replace("Ö", "O")
        => substring(1, 10)
    return
        kmg-edition-nav:entry($doc)
};

declare function kmg-edition-nav:entry($doc as node()*)
as element(toggle-section)*
{
    let $uri := replace(util:document-name($doc), '\..*', '')

    let $year := string-join($doc//tei:sourceDesc//tei:desc[contains(@type, "Leittext")]/tei:date[1]/@when)
    let $year := if ( contains($year, "-") ) then substring-before($year, "-") else $year

    let $title := string-join(transformKMG:transform($doc//tei:title[@type="main"], $uri, "none", "", ""), " ")
    let $subTitle := string-join(transformKMG:transform($doc//tei:title[@type="sub"], $uri, "none", "", ""), " ")
    let $altTitle := string-join(transformKMG:transform($doc//tei:title[@type="alt"], $uri, "none", "", ""), " ")

    let $versions :=  $doc//tei:sourceDesc/tei:listWit/tei:witness[(fn:exists(@xml:id) and not(@sade:singleview/string() = "false"))]

    let $target := "kmg.html?file=" || $uri || "&amp;edition="
    return
        element toggle-section
        {
            attribute data-keywords
            {
                string-join($doc//tei:profileDesc//tei:keywords[not(contains(@scheme, "documenttype"))]/tei:term, "_")
            },
            attribute data-genre
            {
                string-join($doc//tei:profileDesc//tei:keywords/tei:term/@key, "_")
            },
            attribute data-year
            {
                $year
            },
            attribute id
            {
                replace($title, "[\s‹›«»›‹»«‘’“”‚‘„“]", "")
                => replace("Ü", "U")
                => replace("Ä", "A")
                => replace("Ö", "O")
            },
            element h2
            {
                attribute id { replace($title, "[\s]+", "_") => replace("[\s‹›«»›‹»«‘’“”‚‘„“]", "") },
                $title || " (" || $year || ")"
            },
            if ($subTitle) then
                element h3 {
                    attribute class { "nav__sub-title" },
                    $subTitle
                }
            else (),
            if ($altTitle) then
                for $title in $altTitle return
                    element h3 {
                        attribute class { "nav__sub-title" },
                        "(" || $title || ")"
                    }
            else (),
            element ul {
                if (count($versions) = 1) then
                    element li {
                        attribute class { "edition-nav-li" },
                        element a {
                            attribute href { $target || $versions[1]/@xml:id },
                            element span { attribute class { "icon-listarrow" } },
                            $versions[1]/tei:desc
                        }
                    }
                else (
                    element li {
                        attribute class { "edition-nav-li" },
                        element a {
                            attribute href { $target || "digital" },
                            element span {
                                attribute class { "icon-listarrow" }
                            },
                            "Textkritische interaktive Ansicht mit a als Leittext"
                        }
                    },
                    for $version in $versions return
                        if (fn:exists($version/@xml:id) and not($version/@sade:singleview/string() = "false")) then (
                            element li {
                                attribute class { "edition-nav-li" },
                                element a {
                                    attribute href { $target || $version/@xml:id },
                                    element span { attribute class { "icon-listarrow" } },
                                    "Fassung " || $version/@xml:id || ": " || $version/tei:desc
                                }
                            }
                        )
                        else ()
                ),
                element li {
                    attribute class { "edition-nav-li" },
                    element a {
                        attribute href { $target || "commentary" },
                        element span { attribute class { "icon-listarrow" } },
                        "Werkkommentar"
                    }
                }
            }
        }
};

declare function kmg-edition-nav:get-keywords($node as node(), $model as map(*))
{
    let $keywords := kmg-edition-nav:find-unique-keywords()
    for $keyword in $keywords[index-of($keywords, .)[1]]
    return
        element option
        {
            attribute value {$keyword/text()},
            $keyword/text()
        }
};

declare function kmg-edition-nav:find-unique-keywords()
{
    for $doc in collection($config:sade-data)
    let $keywords := $doc//tei:profileDesc//tei:keywords[not(contains(@scheme, "documenttype"))]/tei:term
    return
        $keywords
};

declare function kmg-edition-nav:get-publication-genres($node as node(), $model as map(*))
{
    let $genres := kmg-edition-nav:find-unique-publication-genres()
    for $genre in $genres[index-of($genres, .)[1]]
    return
        element option
        {
            attribute value {
                "documenttype:554dc16e-2e64-452a-88f9-bfb4c2c368a3_"
                ||$genre/@key
            },
            $genre/text()
        }
};

declare function kmg-edition-nav:get-additional-genres($node as node(), $model as map(*))
{
    let $genres := kmg-edition-nav:find-unique-additional-genres()
    for $genre in $genres[index-of($genres, .)[1]]
    return
        element option
        {
            attribute value {
                "documenttype:8525963e-2a7d-4d34-be85-3893039d733e_"
                || $genre/@key
            },
            $genre/text()
        }
};

declare function kmg-edition-nav:find-unique-publication-genres()
{
    for $doc in collection($config:sade-data)
    let $genres := $doc//tei:profileDesc//tei:keywords[contains(@scheme, "documenttype")][tei:term/@key = "documenttype:554dc16e-2e64-452a-88f9-bfb4c2c368a3"]/tei:term[not(@key = "documenttype:554dc16e-2e64-452a-88f9-bfb4c2c368a3")]
    return
        $genres
};

declare function kmg-edition-nav:find-unique-additional-genres()
{
    for $doc in collection($config:sade-data)
    let $genres := $doc//tei:profileDesc//tei:keywords[contains(@scheme, "documenttype")][tei:term/@key = "documenttype:8525963e-2a7d-4d34-be85-3893039d733e"]/tei:term[not(@key = "documenttype:8525963e-2a7d-4d34-be85-3893039d733e")]
    return
        $genres
};
