xquery version "3.1";

module namespace kmg-register="https://mollenhauer-edition.de/ns/register";

declare namespace tei="http://www.tei-c.org/ns/1.0";
declare namespace xhtml="http://www.w3.org/1999/xhtml";
declare namespace index="https://mollenhauer-edition.de/index";

import module namespace config="https://sade.textgrid.de/ns/config" at "../config.xqm";
import module namespace transformKMG="http://mollenhauer-edition.de/ns/transform" at "transform.xqm";
import module namespace kmg-util="http://mollenhauer-edition.de/ns/util" at "kmg-util.xqm";

declare function kmg-register:get-selector($node as node(), $model as map(*))
{
    let $selection := request:get-parameter("register", "person")
    let $registers := ("person", "art", "music")
    let $lang := request:get-parameter("lang", "de")
    let $labels := map:merge((
        map:entry("person",
            map:merge((
                map:entry("de", "Personen"),
                map:entry("en", "Persons")
            ))),
        map:entry("art",
            map:merge((
                map:entry("de", "Kunstwerke"),
                map:entry("en", "Artworks")
            ))),
        map:entry("music",
            map:merge((
                map:entry("de", "Musikwerke"),
                map:entry("en", "Musical Works")
            )))
    ))
    return
        for $register in $registers return
            element a {
                attribute href { "register.html?register=" || $register },
                if ($register eq $selection) then
                    attribute class { "selected" }
                else
                    (),
                $labels($register)($lang)
            }
};

declare function kmg-register:get-registers($node as node(), $model as map(*))
{
    let $selection := request:get-parameter("register", "person")
    let $lang := request:get-parameter("lang", "de")
    let $doc := doc($config:register || $selection || ".xml")
    return
        kmg-register:get-register($doc, $lang)
};

declare function kmg-register:get-register($doc as node()*, $lang as xs:string)
{
    element noscript
    {
        element h2
        {
            switch ($doc/index:index/@type)
            case "person"
            return
                "Personenregister"
            case "art"
            return
                "Register der Kunstwerke"
            case "music"
            return
                "Register der Musikwerke"
            default
            return
                "Register"
        }
    },
    element ol
    {
        attribute class { "index-entries" },
        attribute data-indextype { $doc/index:index/@type },
        attribute role { "list" },
        kmg-register:get-entries($doc, $lang, $doc/index:index/@type)
    }
};

declare function kmg-register:get-entries($doc as node()*, $lang as xs:string, $index as xs:string)
{
    for $entry in kmg-register:sort-entries($doc, $lang, $index)
    let $ref := $entry/@index:ref => substring-after(":")
    return
        element li
        {
            attribute class { "index-entry" },
            if ($index = "art") then
                attribute data-letter { substring($entry/index:name[@xml:lang = $lang]/text(), 1, 1) => lower-case()}
            else
                attribute data-letter { substring($entry/index:name/text(), 1, 1) => lower-case()},
            attribute data-target { $entry/@index:ref => substring-after(":") },
            element details
            {
                attribute id { $entry/@index:ref => substring-after(":") },
                attribute name { "register" },
                element summary {
                    attribute class { "index-entry-head" },
                    if ($index = "art") then
                        $entry/index:name[@xml:lang = $lang]/text()
                    else
                        $entry/index:name/text()
                },
                element dl {
                    attribute class { "index-entry-body" },
                    if ($entry/index:artist) then
                        if ($entry/index:artist/@index:ref) then
                            kmg-register:make-link("Künstler", $entry/index:artist)
                        else
                            kmg-register:make-entry("Komponist", $entry/index:artist/text)
                    else
                        (),
                    if ($entry/index:birth) then
                        kmg-register:make-entry(
                            "Geburtsdatum",
                            try {
                                xs:date($entry/index:birth/text()) => format-date("[D]. [MNn] [Y]", "de", (), ())
                            }
                            catch * {
                                $entry/index:birth/text()
                            })
                    else
                        (),
                    if ($entry/index:death) then
                        kmg-register:make-entry(
                            "Sterbedatum",
                            try {
                                xs:date($entry/index:death/text()) => format-date("[D]. [MNn] [Y]", "de", (), ())
                            }
                            catch * {
                                $entry/index:death/text()
                            })
                    else
                        (),
                    if ($entry/index:date) then
                        kmg-register:make-entry("Entstehungsdatum", $entry/index:date/text())
                    else
                        (),
                    if ($entry/index:place) then
                        kmg-register:make-entry("Entstehungsort", $entry/index:place/text())
                    else
                        (),
                    if ($entry/index:measurements) then
                        kmg-register:make-entry("Maße", $entry/index:measurements/text())
                    else
                        (),
                    if ($entry/index:material) then
                        kmg-register:make-entry("Material/Technik", $entry/index:material/text())
                    else
                        (),
                    if ($entry/index:repository) then
                        kmg-register:make-link("Aufbewahrungsort", $entry/index:repository)
                    else
                        (),
                    if ($entry/index:reproduction) then
                        kmg-register:make-link("Digitalisat", $entry/index:reproduction)
                    else
                        (),
                    if ($entry/index:external) then
                        kmg-register:make-link("Externe Quelle", $entry/index:external)
                    else
                        (),
                    if ($index = "art") then
                        ()
                    else
                        if ($ref) then
                            (element dt {
                                attribute class { "index-entry-label index-entry-source" },
                                "Quelle"
                            },
                                element dd {
                                    attribute class { "index-entry-value" },
                                    element a {
                                        attribute href { "http://d-nb.info/gnd/" || $ref },
                                        attribute target { "_blank" },
                                        "http://d-nb.info/gnd/" || $ref,
                                        " ",
                                        element span {
                                            attribute class { "fa fa-external-link-alt" }
                                        }
                                    }
                                })
                        else
                            (),
                    if ($entry/index:references/*) then
                        (element dt {
                            attribute class { "index-entry-label" },
                            "Nachweise in der Edition"
                        },
                        element dd {
                            attribute class { "index-entry-value" },
                            element ul {
                                attribute role { "list" },
                                for $reference in $entry//index:reference return
                                    element li {
                                        let $doc := doc($config:sade-data || $reference/@index:ref)
                                        let $title := string-join(transformKMG:transform($doc//tei:title[@type="main"], $doc, "none", "", ""), " ")
                                        let $view := kmg-util:getLeittextID($reference/@index:ref)
                                        return
                                            element a {
                                                attribute href {
                                                    "kmg.html?file=" || $reference/@index:ref => replace(".xml", "") || "&amp;edition=" || $view
                                                    },
                                                attribute target { "_blank" },
                                                $title,
                                                " ",
                                                element span {
                                                    attribute class { "fa fa-external-link-alt" }
                                                }
                                            }
                                    }
                            }
                        })
                    else
                        ()
                }
            }
        }
};

declare function kmg-register:make-entry($label as xs:string, $value as xs:string)
{
    element dt {
        attribute class { "index-entry-label" },
        $label
    },
    element dd {
        attribute class { "index-entry-value" },
        $value
    }
};

declare function kmg-register:make-link($label as xs:string, $value as node())
{
    element dt {
        attribute class { "index-entry-label" },
        $label
    },
    element dd {
        attribute class { "index-entry-value" },
        element a {
            attribute href { $value/@index:ref },
            attribute target { "_blank" },
            $value/text(),
            " ",
            element span {
                attribute class { "fa fa-external-link-alt" }
            }
        }
    }
};

declare function kmg-register:sort-entries($doc as node()*, $lang as xs:string, $index as xs:string)
{
    if ($index = "art") then
        for $entry in $doc/index:index/index:body/index:entry
        order by $entry/index:name[@xml:lang = $lang]/text()
        return
            $entry
    else
        for $entry in $doc/index:index/index:body/index:entry
        where substring($entry/index:name/text(), 1, 1) ne "_"
        order by $entry/index:name/text()
        return
            $entry
};