xquery version "3.1";

module namespace kmg-search="https://mollenhauer-edition.de/ns/search";

declare namespace tei="http://www.tei-c.org/ns/1.0";
declare namespace html="http://www.w3.org/1999/xhtml";
declare namespace index="https://mollenhauer-edition.de/index";

import module namespace config="https://sade.textgrid.de/ns/config" at "../../config.xqm";
import module namespace kwic="http://exist-db.org/xquery/kwic";

import module namespace transformKMG="http://mollenhauer-edition.de/ns/transform" at "../transform.xqm";

declare function kmg-search:search-input($node as node(), $model as map(*)) {
    element label {
        attribute class {"search-label"},
        element span {
            "Suchbegriff"
        },
        element input {
            attribute class {"search-input"},
            attribute type {"text"},
            attribute name {"terms"},
            attribute value {request:get-parameter("terms", "")}
        },
        element button {
            attribute class {"search-button"},
            element span {
                attribute class {"fa fa-arrow-right"}
            }
        }
    }
};

declare function kmg-search:search-request($node as node(), $model as map(*)) {
    let $terms := request:get-parameter("terms", "")
    return
    if ($terms eq "") then
        <span>No search term provided</span>
    else
        element div {
            attribute class {"search-area"},
            element div {
                attribute class {"search-facets"},
                element ol {
                    attribute class {"search-list"},
                    attribute role {"list"},
                    element li {
                        attribute class {"search-facet search-facet-active"},
                        element span {
                            attribute class {"fa fa-minus-square"}
                        },
                        element span {
                            "Platzhaler Facette aktiviert"
                        }
                    },
                    element li {
                        attribute class {"search-facet"},
                        element span {
                            attribute class {"fa fa-plus-square"}
                        },
                        element span {
                            "Platzhaler Facette"
                        }
                    },
                    element li {
                        attribute class {"search-facet"},
                        element span {
                            attribute class {"fa fa-plus-square"}
                        },
                        element span {
                            "Platzhaler Facette"
                        }
                    }
                }
            },
            element ul {
                attribute class {"search-list search-results"},
                attribute role {"list"},
                kmg-search:search($terms)
            }
        }
};

declare function kmg-search:search($terms as xs:string*) {
    let $views :=
        map:merge((
            map:entry("commentary", "Werkkommentar")
        ))
    for $hits in collection('/db/data/sade/textgrid/data')//tei:text[ft:query(.,$terms)]
    let $view := if ($hits/@type = "commentary") then "commentary" else ""
    let $doc := doc('/db/data/sade/textgrid/data/' || util:document-name($hits))
    let $uri := replace(util:document-name($hits), '\..*', '')
    let $title := string-join(transformKMG:transform($doc//tei:title[@type="main"], $uri, "none", "", ""), " ")
    let $display-title :=
        if ($hits/@type = "commentary") then
            $title || " (Werkkommentar)"
        else $title
    return
        element li {
            attribute class {"search-result-edition"},
            element h2 {
                attribute class {"search-result-title"},
                $display-title
            },
            element ol {
                attribute class {"search-list search-result-hits"},
                attribute role {"list"},
                for $hit in kwic:summarize($hits, <config width="40"/>)
                return
                    element li {
                        attribute class {"search-result-hit"},
                        element span {
                            attribute class {"fa fa-arrow-right"}
                        },
                        element a {
                            attribute class {"search-result"},
                            attribute href {"kmg.html?file="
                                || util:document-name($hits) => replace(".xml", "")
                                || "&amp;edition="
                                || $view },
                            attribute target {"_blank"},
                            (: hits are returned as html:p, but we only want the contained spans :)
                            $hit/*
                        }
                    }
            }
        }
};